@@ -50,6 +50,15 @@ cpu信息:
         subprocess.getoutput('ip addr'),
         subprocess.getoutput('df -h')
     )
+    # 尝试执行 screenfetch
+    try:
+        res = subprocess.Popen("screenfetch", shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+        sout, serr = res.communicate()
+        # res.returncode, sout, serr, res.pid
+        if res.returncode == 0:
+            memory_info_str += '\nscreenfetch:\n{}'.format(sout.decode('utf-8'))
+    except OSError:
+        pass
     click.echo(memory_info_str)
 
 
